@@ -12,7 +12,7 @@ class AppTest(APITestCase):  # pylint: disable=too-many-ancestors
     def test_root(self):
         """Validate the root for Nautobot Chatops API."""
         url = reverse("plugins-api:nautobot_chatops-api:api-root")
-        response = self.client.get("{}?format=api".format(url), **self.header)
+        response = self.client.get(f"{url}?format=api", **self.header)
 
         self.assertEqual(response.status_code, 200)
 
